@@ -81,7 +81,7 @@ $no25 = 1;                  # officially deprecated format 2.5 tables in MS spec
     'maxMemType42' => 'L',
     'minMemType1' => 'L',
     'maxMemType1' => 'L');
-@base_set = qw(.notdef null CR space exclam quotedbl numbersign dollar percent ampersand quotesingle
+@base_set = qw(.notdef .null nonmarkingreturn space exclam quotedbl numbersign dollar percent ampersand quotesingle
     parenleft parenright asterisk plus comma hyphen period slash zero one two three four five six
     seven eight nine colon semicolon less equal greater question at A B C D E F G H I J K L M N O P Q
     R S T U V W X Y Z bracketleft backslash bracketright asciicircum underscore grave a b c d e f g h
@@ -90,16 +90,16 @@ $no25 = 1;                  # officially deprecated format 2.5 tables in MS spec
     egrave ecircumflex edieresis iacute igrave icircumflex idieresis ntilde oacute ograve ocircumflex
     odieresis otilde uacute ugrave ucircumflex udieresis dagger degree cent sterling section bullet
     paragraph germandbls registered copyright trademark acute dieresis notequal AE Oslash infinity
-    plusminus lessequal greaterequal yen mu1 partialdiff summation product pi integral ordfeminine
+    plusminus lessequal greaterequal yen mu partialdiff summation product pi integral ordfeminine
     ordmasculine Omega ae oslash questiondown exclamdown logicalnot radical florin approxequal
-    increment guillemotleft guillemotright ellipsis nbspace Agrave Atilde Otilde OE oe endash emdash
+    Delta guillemotleft guillemotright ellipsis nonbreakingspace Agrave Atilde Otilde OE oe endash emdash
     quotedblleft quotedblright quoteleft quoteright divide lozenge ydieresis Ydieresis fraction currency
-    guilsinglleft guilsinglright fi fl daggerdbl middot quotesinglbase quotedblbase perthousand
+    guilsinglleft guilsinglright fi fl daggerdbl periodcentered quotesinglbase quotedblbase perthousand
     Acircumflex Ecircumflex Aacute Edieresis Egrave Iacute Icircumflex Idieresis Igrave Oacute Ocircumflex
-    applelogo Ograve Uacute Ucircumflex Ugrave dotlessi circumflex tilde overscore breve dotaccent
+    apple Ograve Uacute Ucircumflex Ugrave dotlessi circumflex tilde macron breve dotaccent
     ring cedilla hungarumlaut ogonek caron Lslash lslash Scaron scaron Zcaron zcaron brokenbar Eth eth
     Yacute yacute Thorn thorn minus multiply onesuperior twosuperior threesuperior onehalf onequarter
-    threequarters franc Gbreve gbreve Idot Scedilla scedilla Cacute cacute Ccaron ccaron dslash);
+    threequarters franc Gbreve gbreve Idotaccent Scedilla scedilla Cacute cacute Ccaron ccaron dcroat);
 
 $VERSION = 0.01;        # MJPH   5-AUG-1998     Re-organise data structures
 
